function [T,C] = readEFNdata(traitfile,treefile)
%Read in the EFN data from a file containing trait information and
%another containing NEWICK of a corresponding tree. 
% Matches the taxon names from both files.

%Read in the tree
phyT = phytreeread(treefile);
T = convertPhytree(phyT);
%Read in the data matrix
fileID = fopen(traitfile);
dataCells = textscan(fileID,'%s %f');
%Match the labels in the datamatrix to labels in the tree.
ntax = size(T.labels,1);
C = zeros(ntax,1);
match = zeros(ntax,1);
dataLabels = dataCells{2};
for n=1:ntax
    label = T.labels{n};
    booleanIndex = strcmp(label, dataCells{1});
    m = find(booleanIndex,1);
    C(n) = dataLabels(m);
    match(n) = m;
end


end



function T = convertPhytree(phyT)
%Convert Phytree format into a structure containing data from the tree.

m = get(phyT,'NumNodes');
n = get(phyT,'NumLeaves');
[M,ID,T.t] = getmatrix(phyT);

T.parent = zeros(m,1);
T.children = zeros(m,2);
T.labels = ID(1:n);
T.nnodes = m;
T.ntax = n;

[row,col] = find(M); 
for i=1:2*(m-n)
    p = row(i);
    c = col(i);
    T.parent(c) = p;
    if T.children(p,1)==0
        T.children(p,1) = c;
    else
        T.children(p,2) = c;
    end
end

end


